@@ -1,6 +1,7 @@
 from pytezos.michelson.types.base import MichelsonType
 from pytezos.michelson.types.big_map import BigMapType
 from pytezos.michelson.types.bls import BLS12_381_FrType, BLS12_381_G1Type, BLS12_381_G2Type
+from pytezos.michelson.types.chest import ChestKeyType, ChestType
 from pytezos.michelson.types.core import BoolType, BytesType, IntType, NatType, NeverType, StringType, UnitType
 from pytezos.michelson.types.domain import (AddressType, ChainIdType, ContractType, KeyHashType, KeyType, LambdaType, MutezType,
                                             SignatureType, TimestampType)
@@ -13,4 +14,3 @@ from pytezos.michelson.types.sapling import SaplingStateType, SaplingTransaction
 from pytezos.michelson.types.set import SetType
 from pytezos.michelson.types.sum import OrType
 from pytezos.michelson.types.ticket import TicketType
-from pytezos.michelson.types.chest import ChestType, ChestKeyType
